#!/bin/bash	
set -e

if [ $(whoami) != "root" ] ; then
echo "Only root should execute this script!"
exit 1
fi

PROGNAME=$(basename $0)
PROGPATH=$(dirname $0)
FULLPATH=$(cd $PROGPATH;pwd)
DESTINATION_DAEMON="/opt/heinlein-elements/mailtrace/daemon"
DESTINATION_WEBGUI="/opt/heinlein-elements/mailtrace"

echo -n "Which destination should be used for the daemon? [/opt/heinlein-elements/mailtrace/daemon]: "
read CUSTOM_DESTINATION_DAEMON
[ -z "$CUSTOM_DESTINATION_DAEMON" ] || DESTINATION_DAEMON=$CUSTOM_DESTINATION_DAEMON
echo -n "Which destination should be used for the webgui? [/opt/heinlein-elements/mailtrace]: "
read CUSTOM_DESTINATION_WEBGUI
[ -z "$CUSTOM_DESTINATION_WEBGUI" ] || DESTINATION_WEBGUI=$CUSTOM_DESTINATION_WEBGUI

echo -n "Copy daemon data to final destination... "
mkdir -p $DESTINATION_DAEMON
cp -a $FULLPATH/daemon/* $DESTINATION_DAEMON/
echo "Done"

echo -n "Copy daemon libs to /usr/lib/perl5... "
[ -d /usr/lib/perl5 ] || mkdir -p /usr/lib/perl5
cp -a $DESTINATION_DAEMON/lib/Mailtrace /usr/lib/perl5/
echo "Done"

echo -n "Copy webgui data to final destination... "
mkdir -p $DESTINATION_WEBGUI
cp -a $FULLPATH/webgui/* $DESTINATION_WEBGUI/
echo "Done"

echo -n "Creating configuration under /etc/mailtrace ..."
mkdir -p /etc/mailtrace
cp -a $FULLPATH/daemon/etc/mailtrace/mailtraced.cfg /etc/mailtrace/
echo "Done"

# Read needed data from user
echo -n "Which DB-Type (POSTGRESQL|mysql): "
read DB_TYPE
[ -z "$DB_TYPE" ] && DB_TYPE="PostgreSQL"
echo -n "IP address of database: "
read DB_IP
if [ "${DB_TYPE,,*}" == "mysql" ] ; then
DB_DEFAULT_PORT=3306
elif [ "${DB_TYPE,,*}" == "postgresql" ] ; then
DB_DEFAULT_PORT=5123
fi
echo -n "Port of database [$DB_DEFAULT_PORT]: "
read DB_PORT
[ -z "$DB_PORT" ] && DB_PORT="$DB_DEFAULT_PORT"
echo -n "What is the db users name: "
read DB_USER
echo -n "What is the db users password: "
read DB_PASSWORD
echo -n "What is the name of the db [mailtrace]: "
read DB_NAME
[ -z "$DB_NAME" ] && DB_NAME="mailtrace"
echo -n "Please enter the path to the maillog [/var/log/mail.info]: "
read MAILLOG_PATH
[ -z "$MAILLOG_PATH" ] && MAILLOG_PATH="/var/log/mail.info"

# Patch the daemon configuration
sed -ir "s/dbtype=.*/dbtype=$DB_TYPE/" /etc/mailtrace/mailtraced.cfg
sed -ir "s/dbport=.*/dbport=$DB_PORT/" /etc/mailtrace/mailtraced.cfg
sed -ir "s/dbuser=.*/dbuser=$DB_USER/" /etc/mailtrace/mailtraced.cfg
sed -ir "s/dbpassword=.*/dbpassword=$DB_PASSWORD/" /etc/mailtrace/mailtraced.cfg
sed -ir "s/dbname=.*/dbname=$DB_NAME/" /etc/mailtrace/mailtraced.cfg
sed -ir "s#logfile_path=.*#logfile_path=$MAILLOG_PATH#" /etc/mailtrace/mailtraced.cfg

# Determine the apache2-user
APACHE_USER=$(ps aux | grep apache2 | grep -v grep | grep -v root | awk {'print $1'} | head -n1)
while true ; do
echo -n "Which user is used to run the apache2? [$APACHE_USER]: "
read CUSTOM_APACHE_USER
[ -z $CUSTOM_APACHE_USER ] || APACHE_USER=$CUSTOM_APACHE_USER
if [ ! -z "$(grep $APACHE_USER /etc/passwd)" ] ; then
break
else
echo "USER not found in passwd!!! Please specify a valid user!"
fi
done

echo -n "Setting appropriate rights... "
for DIRECTORY in  frontend/data/cache/templates frontend/data/cache/zend frontend/data/session frontend/etc frontend/etc/AC frontend/etc/HMT frontend/logs ; do
mkdir -p "$DESTINATION_WEBGUI/$DIRECTORY"
chown -R $APACHE_USER:$APACHE_USER "$DESTINATION_WEBGUI/$DIRECTORY"
chmod -R 775 "$DESTINATION_WEBGUI/$DIRECTORY"
done
echo "Done"

echo -n "Install initscript... "
if [ -f /etc/debian_version ] ; then
cp -a $FULLPATH/daemon/doc/init.d/mailtraced.DEBIAN /etc/init.d/
echo "Done"
elif [ -f /etc/SuSE-release ] ; then
cp -a $FULLPATH/daemon/doc/init.d/mailtraced.SUSE /etc/init.d/
echo "Done"
else
echo "FAILED (No Debian or Suse)"
fi

echo
echo "Installation is finished. Please check the generated configuration under /etc/heinlein-elements/mailtrace.cfg!"
echo -e "\t- Please configure your apache2 that it point to \"$DESTINATION_WEBGUI\""
echo -e "\t- If you want to start mailtrace automatically, link the initscript into the wished runlevel(s)"
echo -e "\t- Add the following into the logrotate configuration block for the maillog file:"
echo -e "\t\t postrotate"
echo -e "\t\t     /etc/init.d/mailtraced stop"
echo -e "\t\t     /etc/init.d/mailtraced start"
echo -e "\t\t endscript"
echo

# Stamp for later uninstallation
echo "# Don't modify or delete this file!" > /etc/mailtrace/.install.log
echo "$DESTINATION_DAEMON" >> /etc/mailtrace/.install.log
echo "$DESTINATION_WEBGUI" >> /etc/mailtrace/.install.log
